@@ -127,6 +127,7 @@ OC.L10N.register(
     "Remove attendee" : "Выдаліць удзельніка",
     "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
     "(organizer)" : "(арганізатар)",
+    "Title" : "Загаловак",
     "From" : "З",
     "To" : "Да",
     "Your Time" : "Ваш час",
@@ -140,7 +141,6 @@ OC.L10N.register(
     "Maybe" : "Магчыма",
     "None" : "Няма",
     "Create" : "Ствараць",
-    "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
     "Global" : "Глабальны",
     "Public calendars" : "Публічныя календары",
     "Select a date" : "Выберыце дату",
@@ -157,11 +157,7 @@ OC.L10N.register(
     "Close" : "Закрыць",
     "Selected" : "Выбрана",
     "No Description" : "Няма апісання",
-    "Title" : "Загаловак",
-    "15 min" : "15 хв",
-    "30 min" : "30 хв",
-    "60 min" : "60 хв",
-    "90 min" : "90 хв",
+    "{duration} min" : "{duration} хв",
     "Participants" : "Удзельнікі",
     "Submit" : "Адправіць",
     "Meeting" : "Сустрэча",
@@ -193,6 +189,11 @@ OC.L10N.register(
     "Show tasks in calendar" : "Паказаць заданні ў календары",
     "Show weekends" : "Паказваць уік-энды",
     "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш",
-    "Successfully appended link to talk room to description." : "Спасылка на пакой у Talk паспяхова дададзена ў апісанне."
+    "Successfully appended link to talk room to description." : "Спасылка на пакой у Talk паспяхова дададзена ў апісанне.",
+    "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
+    "15 min" : "15 хв",
+    "30 min" : "30 хв",
+    "60 min" : "60 хв",
+    "90 min" : "90 хв"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
