@@ -189,6 +189,7 @@ OC.L10N.register(
     "No reminder" : "リマインダーなし",
     "Failed to save default calendar" : "デフォルトカレンダーの保存に失敗しました",
     "General" : "一般",
+    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
     "Appearance" : "表示",
     "Editing" : "編集中",
     "Default reminder" : "既定のリマインダー",
@@ -248,6 +249,7 @@ OC.L10N.register(
     "Select conversation" : "会話を選択",
     "on" : "曜日",
     "at" : "で",
+    "Amount" : "量",
     "before at" : "次の時間分早めに通知",
     "Notification" : "通知",
     "Email" : "メール",
@@ -333,18 +335,16 @@ OC.L10N.register(
     "(organizer)" : "（主催者）",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "招待を送信して返信を受け取るには、[linkopen]個人設定にメールアドレスを追加[linkclose]してください。",
     "Remove color" : "色を削除",
-    "Event title" : "イベントタイトル",
+    "Title" : "タイトル",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "繰り返しの一部であるイベントの終日設定は変更できません。",
     "From" : "開始",
     "To" : "終了",
     "Repeat" : "繰り返し",
     "Repeat event" : "繰り返しイベント",
-    "_time_::_times_" : ["回数"],
     "never" : "なし",
     "on date" : "日時指定",
     "after" : "後",
     "End repeat" : "繰り返し終了",
-    "Select to end repeat" : "繰り返しの終了を選択",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "このイベントは繰り返しセットの反復例外です。それに繰り返しルールを追加することはできません。",
     "first" : "初日",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "繰り返しルールの変更は、今回および今後のすべての開催にのみ適用されます。",
@@ -386,19 +386,6 @@ OC.L10N.register(
     "Maybe" : "たぶん",
     "None" : "なし",
     "Create" : "作成",
-    "from {formattedDate}" : "{formattedDate}から",
-    "to {formattedDate}" : "{formattedDate}まで",
-    "on {formattedDate}" : "{formattedDate} にて",
-    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}から",
-    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}まで",
-    "on {formattedDate} at {formattedTime}" : "{formattedDate} の {formattedTime} に",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
-    "Please enter a valid date" : "有効な日付を入力してください",
-    "Please enter a valid date and time" : "有効な日付と時刻を入力してください",
-    "Select a time zone" : "タイムゾーンの選択",
-    "Please select a time zone:" : "タイムゾーンを選択してください：",
-    "Pick a time" : "時間を指定",
-    "Pick a date" : "日付を指定",
     "Type to search time zone" : "入力してタイムゾーンを検索",
     "Global" : "グローバル",
     "Holidays in {region}" : "{region} の休日",
@@ -447,8 +434,6 @@ OC.L10N.register(
     "Close" : "閉じる",
     "This event was cancelled" : "このイベントはキャンセルされました",
     "Selected" : "選択済み",
-    "Title" : "タイトル",
-    "30 min" : "30分",
     "Participants" : "参加者",
     "Submit" : "提出する",
     "Subscribe to {name}" : "{name} を購読する",
@@ -508,8 +493,8 @@ OC.L10N.register(
     "_+%n more_::_+%n more_" : ["+%n more"],
     "No events" : "イベントはありません",
     "Create a new event or change the visible time-range" : "新規イベントの作成、または表示時間帯の変更",
-    "Failed to save event" : "イベントの保存に失敗しました",
     "It might have been deleted, or there was a typo in a link" : "削除されたか、リンクに誤りがある可能性があります",
+    "Failed to save event" : "イベントの保存に失敗しました",
     "It might have been deleted, or there was a typo in the link" : "削除されたか、リンクに誤りがある可能性があります",
     "Meeting room" : "会議室",
     "Lecture hall" : "講堂",
@@ -558,7 +543,6 @@ OC.L10N.register(
     "Show weekends" : "週末を表示する",
     "Show week numbers" : "週番号を表示する",
     "Time increments" : "時間の増加",
-    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
     "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
     "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
     "Personal availability settings" : "個人の稼働率設定",
@@ -569,6 +553,23 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "通話ルームへのリンクを説明文に追加しました",
     "Error creating Talk room" : "通話ルームの作成に失敗しました",
     "_%n more guest_::_%n more guests_" : ["ゲスト %n 名追加"],
-    "The visibility of this event in shared calendars." : "共有カレンダーでのこのイベントの表示。"
+    "Event title" : "イベントタイトル",
+    "_time_::_times_" : ["回数"],
+    "Select to end repeat" : "繰り返しの終了を選択",
+    "from {formattedDate}" : "{formattedDate}から",
+    "to {formattedDate}" : "{formattedDate}まで",
+    "on {formattedDate}" : "{formattedDate} にて",
+    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}から",
+    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}まで",
+    "on {formattedDate} at {formattedTime}" : "{formattedDate} の {formattedTime} に",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
+    "Please enter a valid date" : "有効な日付を入力してください",
+    "Please enter a valid date and time" : "有効な日付と時刻を入力してください",
+    "Select a time zone" : "タイムゾーンの選択",
+    "Please select a time zone:" : "タイムゾーンを選択してください：",
+    "Pick a time" : "時間を指定",
+    "Pick a date" : "日付を指定",
+    "The visibility of this event in shared calendars." : "共有カレンダーでのこのイベントの表示。",
+    "30 min" : "30分"
 },
 "nplurals=1; plural=0;");
