@@ -300,17 +300,14 @@ OC.L10N.register(
     "(organizer)" : "(organizer)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose].",
     "Remove color" : "Remove color",
-    "Event title" : "Event title",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Cannot modify all-day setting for events that are part of a recurrence-set.",
     "From" : "From",
     "To" : "To",
     "Repeat" : "Repeat",
-    "_time_::_times_" : ["time","times"],
     "never" : "never",
     "on date" : "on date",
     "after" : "after",
     "End repeat" : "End repeat",
-    "Select to end repeat" : "Select to end repeat",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it.",
     "first" : "first",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Changes to the recurrence-rule will only apply to this and all future occurrences.",
@@ -350,18 +347,6 @@ OC.L10N.register(
     "No" : "არა",
     "None" : "None",
     "Create" : "Create",
-    "from {formattedDate}" : "from {formattedDate}",
-    "to {formattedDate}" : "to {formattedDate}",
-    "on {formattedDate}" : "on {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "from {formattedDate} at {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "to {formattedDate} at {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "on {formattedDate} at {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} at {formattedTime}",
-    "Please enter a valid date" : "Please enter a valid date",
-    "Please enter a valid date and time" : "Please enter a valid date and time",
-    "Please select a time zone:" : "Please select a time zone:",
-    "Pick a time" : "Pick a time",
-    "Pick a date" : "Pick a date",
     "Type to search time zone" : "Type to search time zone",
     "Global" : "Global",
     "Holidays in {region}" : "Holidays in {region}",
@@ -406,7 +391,6 @@ OC.L10N.register(
     "Close" : "Close",
     "This event was cancelled" : "This event was cancelled",
     "Selected" : "Selected",
-    "30 min" : "30 წთ",
     "Participants" : "Participants",
     "Submit" : "Submit",
     "Subscribe to {name}" : "Subscribe to {name}",
@@ -521,6 +505,22 @@ OC.L10N.register(
     "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
     "Successfully appended link to talk room to description." : "Successfully appended link to talk room to description.",
     "Error creating Talk room" : "Error creating Talk room",
-    "The visibility of this event in shared calendars." : "The visibility of this event in shared calendars."
+    "Event title" : "Event title",
+    "_time_::_times_" : ["time","times"],
+    "Select to end repeat" : "Select to end repeat",
+    "from {formattedDate}" : "from {formattedDate}",
+    "to {formattedDate}" : "to {formattedDate}",
+    "on {formattedDate}" : "on {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "from {formattedDate} at {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "to {formattedDate} at {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "on {formattedDate} at {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} at {formattedTime}",
+    "Please enter a valid date" : "Please enter a valid date",
+    "Please enter a valid date and time" : "Please enter a valid date and time",
+    "Please select a time zone:" : "Please select a time zone:",
+    "Pick a time" : "Pick a time",
+    "Pick a date" : "Pick a date",
+    "The visibility of this event in shared calendars." : "The visibility of this event in shared calendars.",
+    "30 min" : "30 წთ"
 },
 "nplurals=2; plural=(n!=1);");
