@@ -314,12 +314,11 @@ OC.L10N.register(
     "(organizer)" : "(주최자)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "초대장을 보내거나 답장을 관리하려면, [linkopen] 개인 설정에서 이메일 주소를 추가하십시오[linkclose].",
     "Remove color" : "색깔 삭제",
-    "Event title" : "일정 제목",
+    "Title" : "제목",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "반복하는 이 일정의 \"하루 종일\" 여부를 수정할 수 없습니다.",
     "From" : "시작",
     "To" : "종료",
     "Repeat" : "반복",
-    "_time_::_times_" : ["회"],
     "never" : "없음",
     "on date" : "지정한 날짜에",
     "after" : "이후",
@@ -362,18 +361,6 @@ OC.L10N.register(
     "Maybe" : "아마도",
     "None" : "없음",
     "Create" : "생성",
-    "from {formattedDate}" : "{formattedDate} 부터",
-    "to {formattedDate}" : "{formattedDate} 까지",
-    "on {formattedDate}" : "{formattedDate}에",
-    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 부터",
-    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 까지",
-    "on {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 에",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
-    "Please enter a valid date" : "올바른 날짜를 입력하세요.",
-    "Please enter a valid date and time" : "올바른 날짜와 시간을 입력하세요.",
-    "Please select a time zone:" : "시간대를 선택하세요.",
-    "Pick a time" : "시간 선택",
-    "Pick a date" : "날짜 선택",
     "Type to search time zone" : "시간대를 찾기 위해 입력하세요.",
     "Global" : "국제",
     "Holidays in {region}" : "{region}의 휴일",
@@ -415,8 +402,6 @@ OC.L10N.register(
     "Untitled event" : "제목없는 일정",
     "Close" : "닫기",
     "This event was cancelled" : "이 일정은 취소되었습니다",
-    "Title" : "제목",
-    "30 min" : "30분",
     "Participants" : "참가자",
     "Thank you for your response!" : "답변해 주셔서 감사합니다!",
     "Submit" : "제출",
@@ -529,6 +514,21 @@ OC.L10N.register(
     "Successfully appended link to talk room to location." : "위치에 대화방 링크를 성공적으로 추가함",
     "Successfully appended link to talk room to description." : "설명에 대화방 링크를 성공적으로 추가함",
     "Error creating Talk room" : "대화방 생성 오류",
-    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부"
+    "Event title" : "일정 제목",
+    "_time_::_times_" : ["회"],
+    "from {formattedDate}" : "{formattedDate} 부터",
+    "to {formattedDate}" : "{formattedDate} 까지",
+    "on {formattedDate}" : "{formattedDate}에",
+    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 부터",
+    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 까지",
+    "on {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 에",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
+    "Please enter a valid date" : "올바른 날짜를 입력하세요.",
+    "Please enter a valid date and time" : "올바른 날짜와 시간을 입력하세요.",
+    "Please select a time zone:" : "시간대를 선택하세요.",
+    "Pick a time" : "시간 선택",
+    "Pick a date" : "날짜 선택",
+    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부",
+    "30 min" : "30분"
 },
 "nplurals=1; plural=0;");
