@@ -153,7 +153,6 @@ OC.L10N.register(
     "Share with users or groups" : "Сподели со корисници или групи",
     "No users or groups" : "Нема корисници или групи",
     "Failed to save calendar name and color" : "Неуспешно зачувување на име на календар и боја",
-    "Calendar name …" : "Име на календар …",
     "Never show me as busy (set this calendar to transparent)" : "Никогаш не ме прикажувај зафатен (постави го овој календар транспарентен)",
     "Share calendar" : "Сподели календар",
     "Unshare from me" : "Не споделувај со мене",
@@ -211,6 +210,7 @@ OC.L10N.register(
     "No reminder" : "Нема потсетник",
     "Failed to save default calendar" : "Неуспешно зачувување на стандарден календар",
     "General" : "Општо",
+    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
     "Availability settings" : "Поставки за достапност",
     "CalDAV" : "CalDAV",
     "Access Nextcloud calendars from other apps and devices" : "Пристапете до Nextcloud календарите од други апликации и уреди",
@@ -396,19 +396,17 @@ OC.L10N.register(
     "Make {label} the organizer and attend" : "Постави го {label} како организатор и учествувај",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
     "Remove color" : "Отстрани боја",
-    "Event title" : "Наслов на настанот",
+    "Title" : "Наслов",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не може да се менуваат целодневните параметри за настани што се дел од множество за повторување.",
     "From" : "Од",
     "To" : "До",
     "Your Time" : "Твоето време",
     "Repeat" : "Повтори",
     "Repeat event" : "Повтори настан",
-    "_time_::_times_" : ["еднаш","пати"],
     "never" : "никогаш",
     "on date" : "на датум",
     "after" : "после",
     "End repeat" : "Крај на повторувањето",
-    "Select to end repeat" : "Избери крај на повторувањето",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Овој настан е повторување-исклучок на множество повторување. Не можете да додадете правило за повторување на него.",
     "first" : "прв",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Промените на правилото за повторување ќе важат само за оваа и за сите идни појави.",
@@ -458,19 +456,6 @@ OC.L10N.register(
     "Create a meeting for this date and time" : "Креирај состанок за овој датум и време",
     "Create" : "Креирај",
     "No participants or dates available" : "Нема достапни учесници или датуми.",
-    "from {formattedDate}" : "од {formattedDate}",
-    "to {formattedDate}" : "до {formattedDate}",
-    "on {formattedDate}" : "на {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "од {formattedDate} во {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "до {formattedDate} во {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "на {formattedDate} во {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} во {formattedTime}",
-    "Please enter a valid date" : "Внесете валиден датум",
-    "Please enter a valid date and time" : "Внесете валиден датум и време",
-    "Select a time zone" : "Избери временска зона",
-    "Please select a time zone:" : "Изберете временска зона:",
-    "Pick a time" : "Избери време",
-    "Pick a date" : "Избери датум",
     "Type to search time zone" : "Пребарај временски зони",
     "Global" : "Глобално",
     "Holidays in {region}" : "Празници во {region}",
@@ -544,11 +529,6 @@ OC.L10N.register(
     "No Location" : "Нема локација",
     "Edit this meeting proposal" : "Измени го овој предлог за состанок",
     "Delete this meeting proposal" : "Избриши го овој предлог за состанок",
-    "Title" : "Наслов",
-    "15 min" : "15 мин",
-    "30 min" : "30 мин",
-    "60 min" : "60 мин",
-    "90 min" : "90 мин",
     "Participants" : "Учесници",
     "Selected times" : "Избрани времиња",
     "Previous span" : "Претходен период",
@@ -630,8 +610,8 @@ OC.L10N.register(
     "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
     "No events" : "Нема настани",
     "Create a new event or change the visible time-range" : "Креирајте нов настан или променете го видливиот временски опсег",
-    "Failed to save event" : "Неуспешно зачувување на настанот",
     "It might have been deleted, or there was a typo in a link" : "Можеби е избришан или има грешка во врската",
+    "Failed to save event" : "Неуспешно зачувување на настанот",
     "It might have been deleted, or there was a typo in the link" : "Можеби е избришан или има грешка во врската",
     "Meeting room" : "Соба за состаноци",
     "Lecture hall" : "Сала за предавање",
@@ -686,7 +666,6 @@ OC.L10N.register(
     "Show weekends" : "Прикажи викенди",
     "Show week numbers" : "Прикажи броеви на неделите",
     "Time increments" : "Временско зголемување",
-    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
     "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
     "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
     "Personal availability settings" : "Параметри за лична достапност",
@@ -697,6 +676,27 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
     "Error creating Talk room" : "Грешка при креирање на соба за разговор",
     "_%n more guest_::_%n more guests_" : ["%n гостин","%n други гости"],
-    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар."
+    "Event title" : "Наслов на настанот",
+    "_time_::_times_" : ["еднаш","пати"],
+    "Select to end repeat" : "Избери крај на повторувањето",
+    "from {formattedDate}" : "од {formattedDate}",
+    "to {formattedDate}" : "до {formattedDate}",
+    "on {formattedDate}" : "на {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "од {formattedDate} во {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "до {formattedDate} во {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "на {formattedDate} во {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} во {formattedTime}",
+    "Please enter a valid date" : "Внесете валиден датум",
+    "Please enter a valid date and time" : "Внесете валиден датум и време",
+    "Select a time zone" : "Избери временска зона",
+    "Please select a time zone:" : "Изберете временска зона:",
+    "Pick a time" : "Избери време",
+    "Pick a date" : "Избери датум",
+    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
+    "Calendar name …" : "Име на календар …",
+    "15 min" : "15 мин",
+    "30 min" : "30 мин",
+    "60 min" : "60 мин",
+    "90 min" : "90 мин"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
