@@ -22,6 +22,8 @@ OC.L10N.register(
     "Appointments" : "Afspraken",
     "Schedule appointment \"%s\"" : "Plan afspraak \"%s\"",
     "Schedule an appointment" : "Plan een afspraak",
+    "Requestor Comments:" : "Aanvrager commentaar:",
+    "Appointment Description:" : "Afspraak Omschrijving:",
     "Prepare for %s" : "Voorbereiden op %s",
     "Follow up for %s" : "Follow-up voor %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Je afspraak \"%s\" met %s moet nog bevestigd worden",
@@ -40,8 +42,21 @@ OC.L10N.register(
     "Comment:" : "Opmerking:",
     "You have a new appointment booking \"%s\" from %s" : "Je hebt een nieuwe afspraakboeking \"%s\" van %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Beste %s, %s (%s) heeft een afspraak met je geboekt.",
+    "%s has proposed a meeting" : "%s heeft een bijeenkomst voorgesteld ",
+    "%s has updated a proposed meeting" : "%s heeft een voorgestelde bijeenkomst gewijzigd",
+    "%s has canceled a proposed meeting" : "%s heeft een voorgestelde bijeenkomst afgelast ",
+    "Dear %s, a new meeting has been proposed" : "Beste %s, er is een voorstel voor een nieuwe bijeenkomst ",
+    "Dear %s, a proposed meeting has been updated" : "Beste %s, een voorgestelde bijeenkomst is gewijzigd",
+    "Dear %s, a proposed meeting has been cancelled" : "Beste %s, een voorgestelde bijeenkomst is afgelast",
     "Location:" : "Locatie:",
+    "%1$s minutes" : "%1$s minuten",
     "Duration:" : "Duur:",
+    "%1$s from %2$s to %3$s" : "%1$s van %2$s tot %3$s",
+    "Dates:" : "Data:",
+    "Respond" : "Reageer",
+    "[Proposed] %1$s" : "[Voorstel] %1$s",
+    "Calendar App" : "Kalender App",
+    "Calendars App settings including proposals and appointments schedule configurations." : "Kalender App instellingen, inclusief tijdschema-configuraties voor voorstellen en afspraken.",
     "A Calendar app for Nextcloud" : "Een agenda-app voor Nextcloud",
     "Previous day" : "Vorige dag",
     "Previous week" : "Vorige week",
@@ -138,17 +153,30 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName}(Team)",
     "An error occurred while unsharing the calendar." : "Er is een fout opgetreden bij het delen van de kalender.",
     "An error occurred, unable to change the permission of the share." : "Er is een fout opgetreden, het is niet mogelijk om de machtiging van de share te wijzigen",
+    "can edit and see confidential events" : "kan vertrouwelijke evenementen zien en wijzigen",
     "Unshare with {displayName}" : "Stop delen met {displayName}",
     "Share with users or groups" : "Deel met gebruikers of groepen",
     "No users or groups" : "Geen gebruikers of groepen",
+    "events" : "evenementen",
+    "tasks" : "taken",
+    "journal entries" : "logboekvermeldingen",
+    "This calendar supports neither events, tasks nor journal entries." : "Deze kalender ondersteunt geen evenementen, taken of logboekvermeldingen",
     "Failed to save calendar name and color" : "Niet gelukt om de naam en kleur van de kalender op te slaan",
+    "Calendar name" : "Kalender naam",
     "Never show me as busy (set this calendar to transparent)" : "Toon mij nooit als bezet (stel deze agenda in als transparant)",
     "Share calendar" : "Delen kalender",
     "Unshare from me" : "Stop delen met mij",
     "Save" : "Opslaan",
     "No title" : "Geen titel",
     "Are you sure you want to delete \"{title}\"?" : "Weet je zeker dat je \"{title}\" wilt verwijderen?",
+    "Successfully deleted proposal" : "Voorstel succesvol verwijderd",
+    "Failed to delete proposal" : "Voorstel verwijderen mislukt",
+    "Failed to retrieve proposals" : "Ophalen voorstellen mislukt",
+    "Meeting proposals" : "Voorstellen voor bijeenkomst",
+    "A configured email address is required to use meeting proposals" : "Een geconfigureerd e-mail adres is vereist om bijeenkomsten voor te stellen",
+    "No active meeting proposals" : "Geen actieve bijeenkomst voorstellen",
     "View" : "Bekijken",
+    "Import destination selection" : "Importeer geselecteerde bestemming",
     "Import calendars" : "Importeer agenda's",
     "Please select a calendar to import into …" : "Selecteer een agenda om naar te importeren  ...",
     "Filename" : "Bestandsnaam",
@@ -192,9 +220,22 @@ OC.L10N.register(
     "No reminder" : "Geen herinnering",
     "Failed to save default calendar" : "Kon standaardagenda niet opslaan",
     "General" : "Algemeen",
+    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
+    "Availability settings" : "Beschikbare instellingen",
+    "CalDAV" : "CalDAV",
+    "Access Nextcloud calendars from other apps and devices" : "Toegang tot Nextcloud kalenders vanuit andere applicaties en apparaten",
+    "CalDAV URL" : "CalDAV URL",
+    "Server Address for iOS and macOS" : "Server adres voor iOS en macOS",
     "Appearance" : "Uiterlijk",
+    "Birthday calendar" : "Verjaardagskalender",
+    "Tasks in calendar" : "Taken in de kalender",
+    "Week numbers" : "Weeknummers",
+    "Limit number of events shown in Month view" : "Beperk de evenementen getoond in Maand overzicht",
+    "Density in Day and Week View" : "Dichtheid in Dag en Week overzichten",
     "Editing" : "Bewerken",
     "Default reminder" : "Standaard herinnering",
+    "Simple event editor" : "Eenvoudige evenementen bewerker",
+    "\"More details\" opens the detailed editor" : "\"Meer details\" opent een gedetailleerde bewerker",
     "Files" : "Bestanden",
     "Appointment schedule successfully created" : "Afspraakschema succesvol aangemaakt",
     "Appointment schedule successfully updated" : "Afspraakschema succesvol aangepast",
@@ -251,9 +292,16 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Kon afspraak niet boeken. Probeer later opnieuw of neem contact op met de organisator.",
     "Back" : "Terug",
     "Book appointment" : "Boek afspraak",
+    "Error fetching Talk conversations." : "Fout bij ophalen Talk conversaties",
+    "Conversation does not have a valid URL." : "Conversatie heeft geen geldige URL",
+    "Successfully added Talk conversation link to location." : "Geslaagde toevoeging Talk gesprekskoppeling aan locatie. ",
+    "Successfully added Talk conversation link to description." : "Geslaagde toevoeging Talk gesprekskoppeling aan omschrijving. ",
+    "Failed to apply Talk room." : "Toepassen Talk ruimte mislukt.",
+    "Talk conversation for event" : "Talk gesprek voor evenement",
     "Select conversation" : "Selecteer een gesprek",
     "on" : "op",
     "at" : "om",
+    "Amount" : "Hoeveelheid",
     "before at" : "ervoor om",
     "Notification" : "Melding",
     "Email" : "Email",
@@ -342,17 +390,15 @@ OC.L10N.register(
     "Make {label} the organizer and attend" : "Maak {label} de organisator en neem deel",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Om uitnodigingen te versturen en antwoorden te behandelen,  [linkopen]voeg je e-mailadres toe in persoonlijke instellingen[linkclose].",
     "Remove color" : "Verwijderen kleur",
-    "Event title" : "Afspraaknaam",
+    "Title" : "Titel",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Het lukt niet om de gehele-dag instelling aan te passen voor afspraken die onderdeel zijn van een herhaalde-set.",
     "From" : "Van",
     "To" : "Naar",
     "Repeat" : "Herhaling",
-    "_time_::_times_" : ["keer","keer"],
     "never" : "geen",
     "on date" : "op datum",
     "after" : "na",
     "End repeat" : "Beëindig herhalen",
-    "Select to end repeat" : "Selecteer om herhaling te beëindigen",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Deze afspraak is een uitzondering van een herhaalde-set. Je kunt hieraan geen herhalingsregel toevoegen.",
     "first" : "eerste",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Wijzigingen op de herhaling zal alleen worden toegepast op deze en toekomstige afspraken.",
@@ -393,19 +439,6 @@ OC.L10N.register(
     "No" : "Nee",
     "None" : "Geen",
     "Create" : "Creëer",
-    "from {formattedDate}" : "van {formattedDate}",
-    "to {formattedDate}" : "tot {formattedDate}",
-    "on {formattedDate}" : "op {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "van {formattedDate} om {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "tot {formattedDate} om {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "op {formattedDate} om {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} om {formattedTime}",
-    "Please enter a valid date" : "Geef een geldige datum op",
-    "Please enter a valid date and time" : "Geef een geldige datum en tijdstip op",
-    "Select a time zone" : "Selecteer een tijdzone",
-    "Please select a time zone:" : "Selecteer een tijdzone:",
-    "Pick a time" : "Kies een tijd",
-    "Pick a date" : "Kies een datum",
     "Type to search time zone" : "Type om tijdzone te zoeken",
     "Global" : "Globaal",
     "Holidays in {region}" : "Vakanties in {regio}",
@@ -437,6 +470,7 @@ OC.L10N.register(
     "Personal" : "Persoonlijk",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "De automatisch gedetecteerde tijdzone is UTC.\nDit komt waarschijnlijk door beveiligingsmaatregelen van je webbrowser. Stel de tijdzone handmatig in bij de agenda-instellingen.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Je ingestelde tijdzone ({timezoneId}) werd niet gevonden. Er wordt teruggevallen op UTC.\nWijzig je tijdzone in instellingen en meld het incident.",
+    "Discard changes" : "Negeer wijzigingen",
     "Edit event" : "Bewerk gebeurtenis",
     "Event does not exist" : "Activiteit bestaat niet",
     "Delete this occurrence" : "Verwijder deze afspraak",
@@ -449,9 +483,8 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Bijlagen die gedeelde toegang vereisen","Bijlagen die gedeelde toegang vereisen"],
     "Untitled event" : "Afspraken zonder naam",
     "Close" : "Sluiten",
+    "This event was cancelled" : "Dit evenement is geannuleerd",
     "Selected" : "Geselecteerd",
-    "Title" : "Titel",
-    "30 min" : "30 min",
     "Participants" : "Deelnemers",
     "Submit" : "Indienen",
     "Subscribe to {name}" : "Abonneren op {name}",
@@ -511,8 +544,8 @@ OC.L10N.register(
     "_+%n more_::_+%n more_" : ["+%n meer","+%n meer"],
     "No events" : "Geen activiteiten",
     "Create a new event or change the visible time-range" : "Maak een nieuwe activiteit of wijzig de zichtbare tijdsperiode",
-    "Failed to save event" : "Opslaan van gebeurtenis mislukt",
     "It might have been deleted, or there was a typo in a link" : "Het zou kunnen verwijderd zijn, of er stond een typfout in de link.",
+    "Failed to save event" : "Opslaan van gebeurtenis mislukt",
     "It might have been deleted, or there was a typo in the link" : "Het zou kunnen verwijderd zijn, of er stond een typfout in de link.",
     "Meeting room" : "Meetingroom",
     "Lecture hall" : "Collegezaal",
@@ -560,7 +593,6 @@ OC.L10N.register(
     "Show weekends" : "Toon weekenden",
     "Show week numbers" : "Tonen weeknummers",
     "Time increments" : "Time-toename",
-    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
     "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
     "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
     "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
@@ -569,6 +601,23 @@ OC.L10N.register(
     "Successfully appended link to talk room to location." : "Succesvol de link naar de Talk ruimte aan de locatie toegevoegd.",
     "Successfully appended link to talk room to description." : "Met succes een link naar de gespreksruimte toegevoegd aan de beschrijving.",
     "Error creating Talk room" : "Fout tijdens aanmaken gespreksruimte",
-    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's."
+    "Event title" : "Afspraaknaam",
+    "_time_::_times_" : ["keer","keer"],
+    "Select to end repeat" : "Selecteer om herhaling te beëindigen",
+    "from {formattedDate}" : "van {formattedDate}",
+    "to {formattedDate}" : "tot {formattedDate}",
+    "on {formattedDate}" : "op {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "van {formattedDate} om {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "tot {formattedDate} om {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "op {formattedDate} om {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} om {formattedTime}",
+    "Please enter a valid date" : "Geef een geldige datum op",
+    "Please enter a valid date and time" : "Geef een geldige datum en tijdstip op",
+    "Select a time zone" : "Selecteer een tijdzone",
+    "Please select a time zone:" : "Selecteer een tijdzone:",
+    "Pick a time" : "Kies een tijd",
+    "Pick a date" : "Kies een datum",
+    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's.",
+    "30 min" : "30 min"
 },
 "nplurals=2; plural=(n != 1);");
