@@ -158,7 +158,6 @@ OC.L10N.register(
     "Share with users or groups" : "Dela med användare eller grupper",
     "No users or groups" : "Inga användare eller grupper",
     "Failed to save calendar name and color" : "Det gick inte att spara kalendernamn och färg",
-    "Calendar name …" : "Kalendernamn …",
     "Never show me as busy (set this calendar to transparent)" : "Visa mig aldrig som upptagen (ställ in den här kalendern på transparent)",
     "Share calendar" : "Dela kalender",
     "Unshare from me" : "Sluta dela från mig",
@@ -216,6 +215,7 @@ OC.L10N.register(
     "No reminder" : "Ingen påminnelse",
     "Failed to save default calendar" : "Det gick inte att spara standardkalendern",
     "General" : "Allmänt",
+    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
     "Availability settings" : "Inställningar för tillgänglighet",
     "CalDAV" : "CalDAV",
     "Access Nextcloud calendars from other apps and devices" : "Åtkomst till Nextcloud-kalendrar från andra appar och enheter",
@@ -305,6 +305,7 @@ OC.L10N.register(
     "Create private conversation" : "Skapa privat konversation",
     "on" : "den",
     "at" : "kl",
+    "Amount" : "Antal",
     "before at" : "innan",
     "Notification" : "Notifiering",
     "Email" : "E-post",
@@ -409,19 +410,17 @@ OC.L10N.register(
     "Make {label} the organizer and attend" : "Gör {label} arrangör och delta",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "För att kunna skicka inbjudningar och hantera svar måste du [linkopen]lägga till din e-postadress i inställningarna[linkclose].",
     "Remove color" : "Ta bort färg",
-    "Event title" : "Händelsens titel",
+    "Title" : "Titel",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan inte ändra inställning för heldag när händelsen är återkommande.",
     "From" : "Från",
     "To" : "Till",
     "Your Time" : "Din tid",
     "Repeat" : "Upprepa",
     "Repeat event" : "Upprepa händelse",
-    "_time_::_times_" : ["gång","gånger"],
     "never" : "aldrig",
     "on date" : "på datum",
     "after" : "efter",
     "End repeat" : "Sluta upprepa",
-    "Select to end repeat" : "Välj för att avsluta upprepning",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Den här händelsen är återkommande undantag för en upprepning. Du kan inte lägga till en regel för den.",
     "first" : "första",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Ändringar av återkommande regel gäller endast för denna och alla framtida händelser.",
@@ -471,19 +470,6 @@ OC.L10N.register(
     "Create a meeting for this date and time" : "Skapa ett möte för detta datum och tid",
     "Create" : "Skapa",
     "No participants or dates available" : "Inga deltagare eller datum tillgängliga",
-    "from {formattedDate}" : "från {formattedDate}",
-    "to {formattedDate}" : "till {formattedDate}",
-    "on {formattedDate}" : "på {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "från {formattedDate} kl {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "till {formattedDate} kl {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "på {formattedDate} kl {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} kl {formattedTime}",
-    "Please enter a valid date" : "Ange ett giltigt datum",
-    "Please enter a valid date and time" : "Ange giltigt datum och tid",
-    "Select a time zone" : "Välj en tidszon",
-    "Please select a time zone:" : "Välj en tidszon:",
-    "Pick a time" : "Välj en tidpunkt",
-    "Pick a date" : "Välj ett datum",
     "Type to search time zone" : "Skriv för att söka tidszon",
     "Global" : "Global",
     "Holidays in {region}" : "Helgdagar i {region}",
@@ -557,11 +543,6 @@ OC.L10N.register(
     "No Location" : "Ingen plats",
     "Edit this meeting proposal" : "Redigera detta mötesförslag",
     "Delete this meeting proposal" : "Ta bort detta mötesförslag",
-    "Title" : "Titel",
-    "15 min" : "15 min",
-    "30 min" : "30 min",
-    "60 min" : "60 min",
-    "90 min" : "90 min",
     "Participants" : "Deltagare",
     "Selected times" : "Valda tider",
     "Previous span" : "Föregående intervall",
@@ -643,8 +624,8 @@ OC.L10N.register(
     "_+%n more_::_+%n more_" : ["och %n till","och %n till"],
     "No events" : "Inga händelser",
     "Create a new event or change the visible time-range" : "Skapa ny händelse eller ändra det synliga tidspannet",
-    "Failed to save event" : "Kunde inte spara händelse",
     "It might have been deleted, or there was a typo in a link" : "Den kan ha raderats eller så var länken felaktig",
+    "Failed to save event" : "Kunde inte spara händelse",
     "It might have been deleted, or there was a typo in the link" : "Den kan ha raderats eller så var länken felaktig",
     "Meeting room" : "Mötesrum",
     "Lecture hall" : "Föreläsningssal",
@@ -699,7 +680,6 @@ OC.L10N.register(
     "Show weekends" : "Visa helger",
     "Show week numbers" : "Visa veckonummer",
     "Time increments" : "Tidsintervall",
-    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
     "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
     "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
     "Personal availability settings" : "Dina tillgänglighetsinställningar",
@@ -710,6 +690,27 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "Länk till rum i Talk tillagd i beskrivningen.",
     "Error creating Talk room" : "Kunde inte skapa rum i Talk",
     "_%n more guest_::_%n more guests_" : ["%n gäst till","%n gäster till"],
-    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar."
+    "Event title" : "Händelsens titel",
+    "_time_::_times_" : ["gång","gånger"],
+    "Select to end repeat" : "Välj för att avsluta upprepning",
+    "from {formattedDate}" : "från {formattedDate}",
+    "to {formattedDate}" : "till {formattedDate}",
+    "on {formattedDate}" : "på {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "från {formattedDate} kl {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "till {formattedDate} kl {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "på {formattedDate} kl {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} kl {formattedTime}",
+    "Please enter a valid date" : "Ange ett giltigt datum",
+    "Please enter a valid date and time" : "Ange giltigt datum och tid",
+    "Select a time zone" : "Välj en tidszon",
+    "Please select a time zone:" : "Välj en tidszon:",
+    "Pick a time" : "Välj en tidpunkt",
+    "Pick a date" : "Välj ett datum",
+    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar.",
+    "Calendar name …" : "Kalendernamn …",
+    "15 min" : "15 min",
+    "30 min" : "30 min",
+    "60 min" : "60 min",
+    "90 min" : "90 min"
 },
 "nplurals=2; plural=(n != 1);");
